@@ -167,6 +167,8 @@ class Netsuite:
 
     def generate_rest_client(self, record_types=None):
 
+        print("\nGenerating Client....")
+
         # from urllib.request import urlopen
         # from tempfile import NamedTemporaryFile
         # from shutil import unpack_archive
@@ -195,7 +197,6 @@ class Netsuite:
             'Content-Type': 'application/json'
         }
         result = requests.post('https://api-latest-master.openapi-generator.tech/api/gen/clients/python',headers=headers2, json=data)
-        print(result.json())
 
         # Defining the zip file URL
         url = result.json().get('link')
@@ -204,31 +205,37 @@ class Netsuite:
         filename = url.split('/')[-1]
 
         # Downloading the file by sending the request to the URL
+        print('Downloading Generated Client....')
         req = requests.get(url)
-        print('Downloading Completed')
+        print('Client Downloaded.')
 
         # extracting the zip file contents
+        print('Extracting....')
         file = zipfile.ZipFile(BytesIO(req.content))
         file.extractall(path=self.api_settings.NETSUITE_CLIENT_PATH)
 
 
         client_src = Path.joinpath(Path(self.api_settings.NETSUITE_CLIENT_PATH), f'python-client/netsuite_rest_client')
         class_src = Path.joinpath(Path(netsuite.settings.PACKAGE_DIR), f'netsuite_rest_client/rest_api_client.py')
-        dst = Path(f'{self.api_settings.NETSUITE_CLIENT_PATH}')
+        docs_src = Path.joinpath(Path(self.api_settings.NETSUITE_CLIENT_PATH), f'python-client/docs')
 
+        dst = Path(f'{self.api_settings.NETSUITE_CLIENT_PATH}')
+        print(f'Copying to: {dst}')
         shutil.copytree(client_src, dst, symlinks=True, ignore=None, ignore_dangling_symlinks=False,
                         dirs_exist_ok=True)
+        shutil.copytree(docs_src, dst, symlinks=True, ignore=None, ignore_dangling_symlinks=False,
+                        dirs_exist_ok=True)
 
         shutil.copy(class_src, dst)
 
-        print('Netsuite Rest Client Created')
         # shutil.rmtree(Path.joinpath(Path(self.api_settings.NETSUITE_CLIENT_PATH), 'python-client'))
-        print('temp folder removed.')
+        print('temp folder was removed.')
 
-        print('\n Netsuite is Ready To Go!')
-        print('Usage Example')
-        print('\n ----------------------')
-        print('\nfrom netsuite import Netsuite'
+        print('\nNetsuite client was successfully generated and is ready to use!')
+        print('***************************************************************')
+        print('\nUSAGE')
+        print('----------------------')
+        print('from netsuite import Netsuite'
               '\nfrom netsuite_rest_client import apis, rest_api_client'
               '\nnetsuite = Netsuite()'
               '\nrest_client = rest_api_client.RestApiClient(netsuite)'
